@@ -349,8 +349,10 @@ static void _php_dns_free_res(struct __res_state *res) { /* {{{ */
    Check DNS records corresponding to a given Internet host name or IP address */
 PHP_FUNCTION(dns_check_record)
 {
-	HEADER *hp;
-	querybuf answer;
+#ifndef MAXPACKET
+#define MAXPACKET  8192 /* max packet size used internally by BIND */
+#endif
+	u_char ans[MAXPACKET];
 	char *hostname, *rectype = NULL;
 	size_t hostname_len, rectype_len = 0;
 	int type = T_MX, i;
@@ -408,14 +410,14 @@ PHP_FUNCTION(dns_check_record)
 	res_init();
 #endif
 
-	i = php_dns_search(handle, hostname, C_IN, type, answer.qb2, sizeof answer);
-	php_dns_free_handle(handle);
+	RETVAL_TRUE;
+	i = php_dns_search(handle, hostname, C_IN, type, ans, sizeof(ans));
 
 	if (i < 0) {
-		RETURN_FALSE;
+		RETVAL_FALSE;
 	}
-	hp = (HEADER *)&answer;
-	RETURN_BOOL(ntohs(hp->ancount) != 0);
+
+	php_dns_free_handle(handle);
 }
 /* }}} */
 
@@ -1031,7 +1033,7 @@ PHP_FUNCTION(dns_get_mx)
 	zval *mx_list, *weight_list = NULL;
 	int count, qdc;
 	u_short type, weight;
-	querybuf answer;
+	u_char ans[MAXPACKET];
 	char buf[MAXHOSTNAMELEN];
 	HEADER *hp;
 	u_char *cp, *end;
@@ -1074,14 +1076,16 @@ PHP_FUNCTION(dns_get_mx)
 	res_init();
 #endif
 
-	i = php_dns_search(handle, hostname, C_IN, DNS_T_MX, answer.qb2, sizeof answer);
+	i = php_dns_search(handle, hostname, C_IN, DNS_T_MX, (u_char *)&ans, sizeof(ans));
 	if (i < 0) {
-		php_dns_free_handle(handle);
 		RETURN_FALSE;
 	}
-	hp = (HEADER *)&answer;
-	cp = answer.qb2 + HFIXEDSZ;
-	end = answer.qb2 + i;
+	if (i > (int)sizeof(ans)) {
+		i = sizeof(ans);
+	}
+	hp = (HEADER *)&ans;
+	cp = (u_char *)&ans + HFIXEDSZ;
+	end = (u_char *)&ans +i;
 	for (qdc = ntohs((unsigned short)hp->qdcount); qdc--; cp += i + QFIXEDSZ) {
 		if ((i = dn_skipname(cp, end)) < 0 ) {
 			php_dns_free_handle(handle);
@@ -1103,7 +1107,7 @@ PHP_FUNCTION(dns_get_mx)
 			continue;
 		}
 		GETSHORT(weight, cp);
-		if ((i = dn_expand(answer.qb2, end, cp, buf, sizeof(buf)-1)) < 0) {
+		if ((i = dn_expand(ans, end, cp, buf, sizeof(buf)-1)) < 0) {
 			php_dns_free_handle(handle);
 			RETURN_FALSE;
 		}
@@ -1114,7 +1118,7 @@ PHP_FUNCTION(dns_get_mx)
 		}
 	}
 	php_dns_free_handle(handle);
-	RETURN_BOOL(zend_hash_num_elements(Z_ARRVAL_P(mx_list)) != 0);
+	RETURN_TRUE;
 }
 /* }}} */
 #endif /* HAVE_FULL_DNS_FUNCS */
